/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package org.ow2.petals.tools.channelclient.jmxclient;

import org.ow2.petals.tools.channelclient.jmxclient.exception.ChannelClientDoesNotExistException;
import org.ow2.petals.tools.channelclient.jmxclient.exception.ChannelClientServiceErrorException;
import org.ow2.petals.tools.channelclient.jmxclient.exception.ConnectionErrorException;

/**
 * The Channel JMX Client API
 * 
 * @author mcarpentier - EBM WebSourcing
 */
public final class ChannelClientJMXClient {

    private final static String PETALS_DOMAIN = "Petals";
    
    /** Default Port opened by ChannelClient BC RMI Server
     * TODO: make it configurable
     **/
    public static final int DEFAULT_RMIPORT = 7777;

    private ChannelClientJMXConnection jmxConnection = null;

    /**
     * Creates a new instance of {@link ChannelClientJMXClient}
     * 
     * @param host
     * @param port
     * @param username
     * @param password
     * @throws ConnectionErrorException
     */
    public ChannelClientJMXClient(String host, Integer port, String username, String password)
            throws ConnectionErrorException {
        this.jmxConnection = new ChannelClientJMXConnection(host, port, username, password);
    }

    /**
     * Retrieve the PEtALS Channel Client service client API
     * 
     * @return the Petals Admin service client API
     * @throws PetalsAdminDoesNotExistException
     * @throws PetalsAdminServiceErrorException
     * @throws ConnectionErrorException
     * @throws ChannelClientServiceErrorException
     * @throws ChannelClientDoesNotExistException
     */
    public ChannelClientServiceClient getChannelClientServiceClient()
            throws ConnectionErrorException, ChannelClientDoesNotExistException,
            ChannelClientServiceErrorException {

        return new ChannelClientServiceClient(PETALS_DOMAIN, jmxConnection
                .getMBeanServerConnection());

    }

    /**
     * Release the connection to the JMX server
     * 
     * @throws ConnectionErrorException
     */
    public void disconnect() throws ConnectionErrorException {
        if (this.jmxConnection != null) {
            this.jmxConnection.disconnect();
        }
    }

    /**
     * Check if JMX server is still reachable
     * 
     */
    public boolean isAlive() {
        return this.jmxConnection.isAlive();
    }

}
